@@ -95,7 +95,7 @@ first check it by calling 'check_window()' function'''
         lefttm = 86400+lefttm
 
     if lefttm < 60:
-        raise CallTimeException("Call time must be greater than one minutea as web.whatsapp.com takes some time to load")
+        raise CallTimeException("Call time must be greater than one minute as web.whatsapp.com takes some time to load")
     
     else:
         global sleeptm
